def supportemail():

    """
    Returns the support email address.

    Returns
    -------
    str
        The support email address.
    """

    return 'hejhdiss@gmail.com'
def feedbackemail():
    """
    Returns the email address for sending feedback.

    Returns
    -------
    str
        The email address for sending feedback.
    """

    return 'hejhdiss@gmail.com'
def authorname():

    """
    Returns the name of the author.

    Returns
    -------
    str
        The name of the author.
    """

    return 'Muhammed Shafin P'
def githuburl():
    """
    Returns the URL of the GitHub repository for this project.

    Returns
    -------
    str
        The URL of the GitHub repository for this project.
    """
    

    return 'https://github.com/hejhdiss/ncert_learn.git'
def documentationurl():

    """
    Returns the URL of the documentation for this project.

    Returns
    -------
    str
        The URL of the documentation for this project.
    """

    return "https://hejhdiss.github.io/ncert_learn-website/"
def bugtrackerurl():

    """
    Returns the URL of the bug tracker for this project.

    Returns
    -------
    str
        The URL of the bug tracker for this project.
    """

    return  "https://github.com/hejhdiss/ncert_learn/issues"