# ncert_learn/__init__.py
__version__ = "4.5.10"

from .intfncs import checkprime,factors,len_fibonacci,checkarmstrong,intreverse,checkpalindrome,checkstrong,checkniven,prime,armstrong,strong,niven,palindrome,len_armstrong,len_strong,len_niven,len_palindrome,checkeven,checkodd,checkzero,checknegative,checkpositive,len_prime
from .stkdict import clearstackdict,createstackdict,pushstackdict,popstackdict,peekstackdict,displaymodestackdict# Import functions
from .stklist import createstacklst,clearstacklst,pushstacklst,popstacklst,peekstacklst,displaymodestacklst
from .dat import studyexamples,studyfunctions,studyshort,studymysqlpython,notes,basics,mysqlnotes
from .area import areaofcircle,areaofpolygon,areaofrectangle,areaofsquare,areaoftriangle
from .conversions import integertobinary,integertooctal,integertohexadecimal,binarytointeger
from .mysql_ import mysql_execute_advanced_mode,mysqlconnect,mysqlconnectwithdatabase,mysqlshowdatabases,mysqlcreatedatabase,mysqlshowtables,mysqlshowtablesfromdatabase,mysqldescribetable,mysqldescribetablefromdatabase,mysqlfetchalltable,mysqlfetchalltablefromdatabase,mysqlcreatetable,mysqltableinsert,mysqlrowcounttablefromdatabase,mysqlexecutequery
from .sort import bubblesort,insertionsort
from .text import istextfile,copytextfromonetoanother,opentextfile,addlinetofile,readtextfile,cleartextfile,readspecificline,overwritetextfile,text_file_operations_advanced_mode
from .os import getexecutablepath,cpucount,listdir,listdirfrompath,osname,processorname,isnetworkconnected,getpythoninterpreter
from .packageinstall import install_library,install_librariesfromlist
from .support import supportemail,feedbackemail,bugtrackerurl,githuburl,documentationurl,authorname
from .time import currenttime,processtime,monotonic,threadtime
from .binary import isbinaryfile,copybinaryfromonetoanother,openbinaryfile,addtextobinaryfile,readbinaryfile,clearbinaryfile,readbinaryspecificchunk,overwritebinaryfile,binary_file_operations_advanced_mode
from .csv import iscsvfile,copycsvfromonetoanother,opencsvfile,addrowtocsv,readcsvfile,clearcsvfile,readcsvspecificline,overwritecsvfile,csv_file_operations_advanced_mode
from .xampp import check_xampp_files,is_process_running_xampp,stop_xampp_mysql,stop_xampp_apache,start_xampp_mysql,start_xampp_apache,start_xampp_mysql,start_xampp_apache,check_phpmyadmin_accessible,start_xampp_and_open_phpmyadmin
from .nmapinstall import  install_and_setup_nmap
from .zip import zip_is_supported_file,zip_is_supported,zip_list_files,zip_extract_file,zip_add_file,zip_extract_all
# __init__.py in your sqlmap directory
from .fileaccess import check_file_existence,create_directory,download_file,get_file_size,get_file_last_modified,rename_file,delete_file,move_file,extract_zip,compress_files,get_url_status,fetch_url_content,download_files_from_urls,get_files_in_directory,count_lines_in_file,get_current_datetime,get_extension,get_file_name_without_extension,get_file_type,move_files_to_directory
from .sqlmap import (
    sqlmap_scan, sqlmap_api_call, sqlmap_scan_for_union_based_sql_injection, 
    sqlmap_scan_for_error_based_sql_injection, sqlmap_scan_for_time_based_sql_injection,
    sqlmap_scan_for_boolean_blind_sql_injection, sqlmap_scan_for_stacked_queries, 
    sqlmap_scan_for_tautology_based_sql_injection, sqlmap_scan_for_second_order_sql_injection,
    sqlmap_scan_for_inline_query_sql_injection, sqlmap_scan_for_blind_time_based_sql_injection,
    sqlmap_scan_with_cookie_based_auth, sqlmap_scan_with_jwt_token, sqlmap_scan_with_basic_auth,
    sqlmap_scan_with_digest_auth, sqlmap_scan_with_ntlm_auth, sqlmap_scan_with_custom_proxy,
    sqlmap_scan_with_socks_proxy, sqlmap_scan_with_multiple_proxies, sqlmap_scan_with_custom_user_agent,
    sqlmap_scan_with_timeout, sqlmap_scan_with_max_redirects, sqlmap_scan_with_retries,
    sqlmap_scan_with_quiet_mode, sqlmap_scan_with_verbosity, sqlmap_scan_for_os_command_injection,
    sqlmap_scan_for_os_command_injection_using_shell, sqlmap_scan_for_os_command_injection_with_wildcards,
    sqlmap_scan_for_local_file_inclusion, sqlmap_scan_for_remote_file_inclusion, sqlmap_scan_for_file_read,
    sqlmap_scan_for_file_upload, sqlmap_scan_for_reflected_xss, sqlmap_scan_for_stored_xss, 
    sqlmap_scan_for_dom_xss, sqlmap_scan_for_mysql_version, sqlmap_scan_for_postgresql_version, 
    sqlmap_scan_for_oracle_version, sqlmap_scan_for_mssql_version, sqlmap_scan_with_error_handling,
    sqlmap_scan_with_logging, sqlmap_api_status_check, sqlmap_scan_with_custom_payloads,
    sqlmap_scan_with_network_error_simulation, sqlmap_scan_with_json_output, bulk_sqlmap_scan, 
    sqlmap_api_start_scan, sqlmap_api_get_scan_status, sqlmap_scan_with_timeout_and_retries, 
    sqlmap_api_terminate_scan, sqlmap_scan_for_union_based_sql_injection, sqlmap_scan_for_syntax_based_sql_injection,
    sqlmap_scan_for_time_based_sql_injection, sqlmap_scan_for_error_based_sql_injection, sqlmap_scan_for_blind_sql_injection,
    sqlmap_scan_with_response_timeout, sqlmap_scan_with_retry, sqlmap_scan_with_max_redirects, 
    sqlmap_scan_with_basic_auth, sqlmap_scan_with_digest_auth, sqlmap_scan_with_ntlm_auth, 
    sqlmap_scan_with_custom_payload, sqlmap_scan_with_multiple_payloads, sqlmap_scan_with_custom_proxy, 
    sqlmap_scan_with_socks_proxy, sqlmap_scan_with_multiple_proxies, sqlmap_scan_with_quiet_mode,
    sqlmap_scan_with_verbosity, sqlmap_scan_with_output_log, sqlmap_scan_with_sqli_check,
    sqlmap_scan_with_xss_check, sqlmap_scan_for_file_inclusion, sqlmap_scan_for_remote_file_inclusion,
    sqlmap_scan_with_stacked_queries, sqlmap_scan_with_sqli_privesc, sqlmap_scan_for_boolean_blind, 
    sqlmap_scan_for_time_based_blind, sqlmap_scan_with_union_query_injection, sqlmap_scan_for_directory_traversal, 
    sqlmap_scan_for_file_read, sqlmap_scan_for_file_upload, sqlmap_scan_with_custom_headers,
    sqlmap_scan_with_custom_cookies, sqlmap_scan_with_user_agent, sqlmap_scan_for_mysql_version, 
    sqlmap_scan_for_postgresql_version, sqlmap_scan_for_oracle_version, sqlmap_scan_for_mssql_version, 
    sqlmap_scan_for_reflected_xss, sqlmap_scan_for_stored_xss, sqlmap_scan_for_dom_xss, 
    sqlmap_scan_with_session_storage, sqlmap_scan_with_cookie_based_auth, sqlmap_scan_with_basic_auth,
    sqlmap_scan_with_jwt_auth, sqlmap_cleanup, sqlmap_scan_for_union_based_sql_injection,
    sqlmap_scan_for_error_based_sql_injection, sqlmap_scan_for_time_based_sql_injection, 
    sqlmap_scan_for_boolean_blind_sql_injection, sqlmap_scan_for_stack_based_sql_injection, 
    sqlmap_scan_for_tautology_based_sql_injection, sqlmap_scan_with_cookie_based_auth, sqlmap_scan_with_jwt_token,
    sqlmap_scan_with_basic_auth, sqlmap_scan_with_digest_auth, sqlmap_scan_with_ntlm_auth, sqlmap_scan_with_custom_proxy,
    sqlmap_scan_with_socks_proxy, sqlmap_scan_with_multiple_proxies, sqlmap_scan_with_custom_user_agent, 
    sqlmap_scan_with_timeout, sqlmap_scan_with_max_redirects, sqlmap_scan_with_retries, 
    sqlmap_scan_with_quiet_mode, sqlmap_scan_with_verbosity, sqlmap_scan_for_boolean_based_blind_injection,
    sqlmap_scan_for_time_based_blind_injection, sqlmap_scan_for_stack_based_blind_injection, 
    sqlmap_scan_for_os_command_injection, sqlmap_scan_for_os_command_injection_using_shell,
    sqlmap_scan_for_os_command_injection_with_wildcards, sqlmap_scan_for_local_file_inclusion, 
    sqlmap_scan_for_remote_file_inclusion, sqlmap_scan_for_file_read, sqlmap_scan_for_file_upload, 
    sqlmap_cleanup, sqlmap_scan_with_custom_payload, sqlmap_scan_with_multiple_payloads, 
    sqlmap_scan_with_random_payloads, sqlmap_scan_for_reflected_xss, sqlmap_scan_for_stored_xss, 
    sqlmap_scan_for_dom_xss, sqlmap_scan_for_mysql_version, sqlmap_scan_for_postgresql_version,
    sqlmap_scan_for_oracle_version, sqlmap_scan_for_mssql_version, sqlmap_scan_with_error_handling,
    sqlmap_scan_for_union_based_sql_injection, sqlmap_scan_for_error_based_sql_injection,
    sqlmap_scan_for_time_based_sql_injection, sqlmap_scan_for_boolean_blind_sql_injection,
    sqlmap_scan_for_stacked_queries, sqlmap_scan_for_second_order_sql_injection, 
    sqlmap_scan_with_cookie_based_auth, sqlmap_scan_with_jwt_token, sqlmap_scan_with_basic_auth,
    sqlmap_scan_with_digest_auth, sqlmap_scan_with_ntlm_auth, sqlmap_scan_with_custom_proxy,
    sqlmap_scan_with_socks_proxy, sqlmap_scan_with_multiple_proxies, sqlmap_scan_with_custom_user_agent,
    sqlmap_scan_with_timeout, sqlmap_scan_with_max_redirects, sqlmap_scan_with_retries, 
    sqlmap_scan_with_quiet_mode, sqlmap_scan_with_verbosity, sqlmap_scan_for_os_command_injection,
    sqlmap_scan_for_os_command_injection_using_shell, sqlmap_scan_for_os_command_injection_with_wildcards,
    sqlmap_scan_for_local_file_inclusion, sqlmap_scan_for_remote_file_inclusion, sqlmap_scan_for_file_read,
    sqlmap_scan_for_file_upload, sqlmap_cleanup, sqlmap_scan_with_custom_payload, 
    sqlmap_scan_with_multiple_payloads, sqlmap_scan_with_random_payloads, sqlmap_scan_for_reflected_xss,
    sqlmap_scan_for_stored_xss, sqlmap_scan_for_dom_xss, sqlmap_scan_for_mysql_version, 
    sqlmap_scan_for_postgresql_version, sqlmap_scan_for_oracle_version, sqlmap_scan_for_mssql_version,
    sqlmap_scan_with_error_handling
)
from .googlesearch_ import getgoogleanswer,get_google_answer
from .nmap import (nmap_scan,nmap_intense_scan,nmap_quick_scan,nmap_ping_sweep,nmap_os_detection,nmap_service_version_detection,nmap_tcp_connect_scan,nmap_syn_scan,nmap_udp_scan,nmap_traceroute_scan,nmap_vulnerability_scan,nmap_stealth_scan,nmap_ack_scan,nmap_window_scan,nmap_masquerade_scan,nmap_decoy_scan,nmap_fin_scan,nmap_xmas_scan,nmap_null_scan,nmap_ping_scan,nmap_sweep_scan,nmap_ftp_scan,nmap_smtp_scan,nmap_dns_scan,nmap_http_scan,nmap_pop3_scan,nmap_ssh_scan,nmap_mysql_scan,nmap_smb_vuln_scan,nmap_http_favicon_scan,nmap_smb_share_scan,nmap_traffic_analysis,nmap_smtp_vuln_scan,nmap_rdp_vuln_scan,nmap_irc_scan,nmap_ldap_scan,nmap_snmp_scan,nmap_dns_vuln_scan,nmap_http_auth_scan,nmap_telnet_scan,nmap_mysql_brute_scan,nmap_smb_info_scan,nmap_nfs_scan,nmap_mongodb_scan,nmap_dhcp_scan,nmap_vnc_scan,nmap_ftp_anonymous_scan,nmap_smtp_enum_scan,nmap_ftp_banners_scan,nmap_smb_enum_users_scan,nmap_ssh_enum_users_scan,nmap_pop3_brute_scan,nmap_tcp_ping_scan,nmap_ssl_scan,nmap_ssl_vuln_scan,nmap_smb_file_scan,nmap_ftp_banners_scan,nmap_vuln_detection_scan,nmap_smtp_open_scan,nmap_http_methods_scan,nmap_ssh_vuln_scan,nmap_http_xss_scan,nmap_ftp_anonymous_scan,nmap_dhcp_discovery_scan,nmap_nfs_mount_scan,nmap_smtp_brute_scan,nmap_smb_brute_scan,nmap_ldap_enum_scan,nmap_http_sitemap_scan,nmap_ftp_version_scan,nmap_snmp_community_scan,nmap_ssh_version_scan,nmap_mysql_info_scan,nmap_dns_zone_transfer_scan,nmap_pop3_vuln_scan,nmap_telnet_vuln_scan,nmap_imap_brute_scan,nmap_irc_banners_scan,nmap_http_ssl_scan,nmap_smb_vuln2_scan,nmap_http_robots_scan,nmap_mssql_brute_scan,nmap_smb_security_scan,nmap_smtp_starttls_scan,nmap_ftp_bypass_scan,nmap_dhcp_server_scan,nmap_dns_traceroute_scan,nmap_smtp_enum_vuln_scan,nmap_dns_dos_scan,nmap_rpc_scan,nmap_mongodb_bypass_scan,nmap_smb_enum_shares_scan,nmap_fingerprint_scan,nmap_snmp_enum_users_scan,nmap_ssl_certificate_scan,nmap_dhcp_lease_scan,nmap_mysql_enum_scan,nmap_http_security_scan,nmap_telnet_enum_scan,nmap_ftp_enumerate_scan,nmap_smb_enum_users_scan,nmap_pop3_enum_scan,nmap_smtp_enum_scan,nmap_http_cookie_scan,nmap_dhcp_fingerprint_scan,nmap_smb_enum_shares_users_scan,nmap_ftp_version_vuln_scan,nmap_smb_session_scan,nmap_telnet_enumerate_scan,nmap_smtp_vuln_scan,nmap_finger_scan,nmap_ftp_login_scan,nmap_ssh_brute_scan,nmap_http_ssl_cc_scan,nmap_smtp_starttls_vuln_scan,nmap_https_ping_scan,nmap_http_user_agent_scan,nmap_http_open_redirect_scan,nmap_smb_domain_info_scan,nmap_rdp_scan,nmap_dns_recursion_scan,nmap_http_ssl_scan,nmap_mongodb_auth_scan,nmap_http_basic_auth_brute_scan,nmap_ftp_vuln_scan,nmap_snmp_enumerate_users_scan,nmap_ssl_scan,nmap_netbios_scan,nmap_mysql_enum_vuln_scan,nmap_dns_scan,nmap_fingerprint_scan,nmap_smb_enum_machine_scan,nmap_smtp_tls_vuln_scan)
from .cmd import(execute_command,cmd_list_files,cmd_get_disk_usage,cmd_get_memory_usage,cmd_get_running_processes,cmd_kill_process,cmd_create_directory,cmd_delete_file_or_directory,cmd_get_system_uptime,cmd_get_kernel_version,cmd_get_system_load,cmd_check_for_updates,cmd_install_package,cmd_uninstall_package,cmd_get_active_users,cmd_get_ip_address,cmd_check_firewall_status,cmd_flush_dns_cache,cmd_get_system_temperature,cmd_reset_tcpip_stack,cmd_check_disk_for_errors,cmd_restart_system,cmd_shutdown_system,cmd_open_control_panel,cmd_open_task_manager,cmd_check_services,cmd_start_service,cmd_stop_service,cmd_view_env_variables)
from .getfunctions import get_function_names_from_python_file
from .engine import engine_save_model,engine_load_model,engine_tensor_add,engine_tensor_dot,engine_sigmoid_activation,engine_dense_layer,engine_sgd_optimizer,engine_mse_loss,test_engine_functions
from .pdfextract import extract_text_from_pdf,save_text_to_file
from .lstfncs import list_append_item, list_remove_item, list_insert_item, list_pop_item, list_find_index, list_contains_item, list_sort, list_reverse, list_clear, list_copy, list_extend, list_count, list_min, list_max, list_sum, list_mean, list_unique, list_combine, list_difference, list_intersection, list_is_empty
from .strfncs import str_reverse, str_to_upper, str_to_lower, str_is_palindrome, str_count_occurrences, str_is_alpha, str_is_digit, str_find_substring, str_replace_substring, str_split_words, str_strip_spaces, str_startswith, str_endswith, str_isalnum, str_title_case, str_concat, str_join
from .dictfncs import dict_add_key_value, dict_remove_key, dict_get_value, dict_update_value, dict_contains_key, dict_get_all_keys, dict_get_all_values, dict_clear, dict_copy, dict_items, dict_pop_item, dict_update, dict_setdefault, dict_fromkeys, dict_get_key_with_max_value, dict_get_key_with_min_value
from .advancedmodeforpg import adv_gcd, adv_lcm, adv_prime_factors, adv_is_prime, adv_modular_exponentiation, adv_is_perfect_square, adv_fast_fourier_transform, adv_hash_string, adv_fast_modular_inverse, adv_fibonacci, adv_sieve_of_eratosthenes, adv_modular_square_root, adv_random_prime, adv_sum_of_squares, adv_calculate_modular_power, adv_combinations, adv_permutations
# Optional: List functions to include in 'import *' cal
__all__ = ['mysqlconnectwithdatabase','exampleusage','checkprime','factors','len_fibonacci','checkarmstrong','intreverse','checkpalindrome','checkstrong','checkniven','prime','armstrong','strong','niven','palindrome','len_armstrong','len_strong','len_niven','len_palindrome','checkeven','checkodd','checkzero','checknegative','checkpositive','clearstackdict','createstackdict','pushstackdict','popstackdict','peekstackdict','displaymodestackdict','createstacklst','clearstacklst','pushstacklst','popstacklst','peekstacklst','displaymodestacklst','studyexamples','studyfunctions','studyshort','studymysqlpython','notes','basics','extendednotes','mysqlnotes'
           ,'bubblesort','insertionsort','mysqlconnect','mysqlshowdatabases','mysqlcreatedatabase','mysqlshowtables','mysqlshowtablesfromdatabase','mysqldescribetable','mysqldescribetablefromdatabase','mysqlfetchalltable','mysqlfetchalltablefromdatabase','mysqlcreatetable','mysqltableinsert','mysqlrowcounttablefromdatabase','mysqlexecutequery',
           'integertobinary','integertooctal','integertohexadecimal','binarytointeger','areaofcircle','areaofpolygon','areaofrectangle','areaofsquare','areaoftriangle',
           'istextfile','copytextfromonetoanother','opentextfile','addlinetofile','readtextfile','cleartextfile','readspecificline',
           'getexecutablepath','cpucount','listdir','listdirfrompath','osname','processorname','isnetworkconnected','getpythoninterpreter',
           'install_library','install_librariesfromlist',
           'supportemail','feedbackemail','bugtrackerurl','githuburl','documentationurl','authorname',
           'currenttime','processtime','monotonic','threadtime',
           'isbinaryfile','copybinaryfromonetoanother','openbinaryfile','addtextobinaryfile','readbinaryfile','clearbinaryfile','readbinaryspecificchunk',
           'iscsvfile','copycsvfromonetoanother','opencsvfile','addrowtocsv','readcsvfile','clearcsvfile','readcsvspecificline',
           'check_xampp_files','is_process_running_xampp','stop_xampp_mysql','stop_xampp_apache','start_xampp_mysql','start_xampp_apache','start_xampp_mysql','start_xampp_apache','check_phpmyadmin_accessible','start_xampp_and_open_phpmyadmin',
           'zip_is_supported_file','zip_is_supported','zip_list_files','zip_extract_file','zip_add_file','zip_extract_all',
           'sqlmap_scan', 'sqlmap_api_call', 'sqlmap_scan_for_union_based_sql_injection', 'sqlmap_scan_for_error_based_sql_injection', 'sqlmap_scan_for_time_based_sql_injection', 'sqlmap_scan_for_boolean_blind_sql_injection', 'sqlmap_scan_for_stacked_queries', 'sqlmap_scan_for_tautology_based_sql_injection', 'sqlmap_scan_for_second_order_sql_injection', 'sqlmap_scan_for_inline_query_sql_injection', 'sqlmap_scan_for_blind_time_based_sql_injection', 'sqlmap_scan_with_cookie_based_auth', 'sqlmap_scan_with_jwt_token', 'sqlmap_scan_with_basic_auth', 'sqlmap_scan_with_digest_auth', 'sqlmap_scan_with_ntlm_auth', 'sqlmap_scan_with_custom_proxy', 'sqlmap_scan_with_socks_proxy', 'sqlmap_scan_with_multiple_proxies', 'sqlmap_scan_with_custom_user_agent', 'sqlmap_scan_with_timeout', 'sqlmap_scan_with_max_redirects', 'sqlmap_scan_with_retries', 'sqlmap_scan_with_quiet_mode', 'sqlmap_scan_with_verbosity', 'sqlmap_scan_for_os_command_injection', 'sqlmap_scan_for_os_command_injection_using_shell', 'sqlmap_scan_for_os_command_injection_with_wildcards', 'sqlmap_scan_for_local_file_inclusion', 'sqlmap_scan_for_remote_file_inclusion', 'sqlmap_scan_for_file_read', 'sqlmap_scan_for_file_upload', 'sqlmap_scan_for_reflected_xss', 'sqlmap_scan_for_stored_xss', 'sqlmap_scan_for_dom_xss', 'sqlmap_scan_for_mysql_version', 'sqlmap_scan_for_postgresql_version', 'sqlmap_scan_for_oracle_version', 'sqlmap_scan_for_mssql_version', 'sqlmap_scan_with_error_handling', 'sqlmap_scan_with_logging', 'sqlmap_api_status_check', 'sqlmap_scan_with_custom_payloads', 'sqlmap_scan_with_network_error_simulation', 'sqlmap_scan_with_json_output', 'bulk_sqlmap_scan', 'sqlmap_api_start_scan', 'sqlmap_api_get_scan_status', 'sqlmap_scan_with_timeout_and_retries', 'sqlmap_api_terminate_scan', 'sqlmap_scan_for_union_based_sql_injection', 'sqlmap_scan_for_syntax_based_sql_injection', 'sqlmap_scan_for_time_based_sql_injection', 'sqlmap_scan_for_error_based_sql_injection', 'sqlmap_scan_for_blind_sql_injection', 'sqlmap_scan_with_response_timeout', 'sqlmap_scan_with_retry', 'sqlmap_scan_with_max_redirects', 'sqlmap_scan_with_basic_auth', 'sqlmap_scan_with_digest_auth', 'sqlmap_scan_with_ntlm_auth', 'sqlmap_scan_with_custom_payload', 'sqlmap_scan_with_multiple_payloads', 'sqlmap_scan_with_custom_proxy', 'sqlmap_scan_with_socks_proxy', 'sqlmap_scan_with_multiple_proxies', 'sqlmap_scan_with_quiet_mode', 'sqlmap_scan_with_verbosity', 'sqlmap_scan_with_output_log', 'sqlmap_scan_with_sqli_check', 'sqlmap_scan_with_xss_check', 'sqlmap_scan_for_file_inclusion', 'sqlmap_scan_for_remote_file_inclusion', 'sqlmap_scan_with_stacked_queries', 'sqlmap_scan_with_sqli_privesc', 'sqlmap_scan_for_boolean_blind', 'sqlmap_scan_for_time_based_blind', 'sqlmap_scan_with_union_query_injection', 'sqlmap_scan_for_directory_traversal', 'sqlmap_scan_for_file_read', 'sqlmap_scan_for_file_upload', 'sqlmap_scan_with_custom_headers', 'sqlmap_scan_with_custom_cookies', 'sqlmap_scan_with_user_agent', 'sqlmap_scan_for_mysql_version', 'sqlmap_scan_for_postgresql_version', 'sqlmap_scan_for_oracle_version', 'sqlmap_scan_for_mssql_version', 'sqlmap_scan_for_reflected_xss', 'sqlmap_scan_for_stored_xss', 'sqlmap_scan_for_dom_xss', 'sqlmap_scan_with_session_storage', 'sqlmap_scan_with_cookie_based_auth', 'sqlmap_scan_with_basic_auth', 'sqlmap_scan_with_jwt_auth', 'sqlmap_cleanup', 'sqlmap_scan_for_union_based_sql_injection', 'sqlmap_scan_for_error_based_sql_injection', 'sqlmap_scan_for_time_based_sql_injection', 'sqlmap_scan_for_boolean_blind_sql_injection', 'sqlmap_scan_for_stack_based_sql_injection', 'sqlmap_scan_for_tautology_based_sql_injection', 'sqlmap_scan_with_cookie_based_auth', 'sqlmap_scan_with_jwt_token', 'sqlmap_scan_with_basic_auth', 'sqlmap_scan_with_digest_auth', 'sqlmap_scan_with_ntlm_auth', 'sqlmap_scan_with_custom_proxy', 'sqlmap_scan_with_socks_proxy', 'sqlmap_scan_with_multiple_proxies', 'sqlmap_scan_with_custom_user_agent', 'sqlmap_scan_with_timeout', 'sqlmap_scan_with_max_redirects', 'sqlmap_scan_with_retries', 'sqlmap_scan_with_quiet_mode', 'sqlmap_scan_with_verbosity', 'sqlmap_scan_for_boolean_based_blind_injection', 'sqlmap_scan_for_time_based_blind_injection', 'sqlmap_scan_for_stack_based_blind_injection', 'sqlmap_scan_for_os_command_injection', 'sqlmap_scan_for_os_command_injection_using_shell', 'sqlmap_scan_for_os_command_injection_with_wildcards', 'sqlmap_scan_for_local_file_inclusion', 'sqlmap_scan_for_remote_file_inclusion', 'sqlmap_scan_for_file_read', 'sqlmap_scan_for_file_upload', 'sqlmap_cleanup', 'sqlmap_scan_with_custom_payload', 'sqlmap_scan_with_multiple_payloads', 'sqlmap_scan_with_random_payloads', 'sqlmap_scan_for_reflected_xss', 'sqlmap_scan_for_stored_xss', 'sqlmap_scan_for_dom_xss', 'sqlmap_scan_for_mysql_version', 'sqlmap_scan_for_postgresql_version', 'sqlmap_scan_for_oracle_version', 'sqlmap_scan_for_mssql_version', 'sqlmap_scan_with_error_handling', 'sqlmap_scan_for_union_based_sql_injection', 'sqlmap_scan_for_error_based_sql_injection', 'sqlmap_scan_for_time_based_sql_injection', 'sqlmap_scan_for_boolean_blind_sql_injection', 'sqlmap_scan_for_stacked_queries', 'sqlmap_scan_for_second_order_sql_injection', 'sqlmap_scan_with_cookie_based_auth', 'sqlmap_scan_with_jwt_token', 'sqlmap_scan_with_basic_auth', 'sqlmap_scan_with_digest_auth', 'sqlmap_scan_with_ntlm_auth', 'sqlmap_scan_with_custom_proxy', 'sqlmap_scan_with_socks_proxy', 'sqlmap_scan_with_multiple_proxies', 'sqlmap_scan_with_custom_user_agent', 'sqlmap_scan_with_timeout', 'sqlmap_scan_with_max_redirects', 'sqlmap_scan_with_retries', 'sqlmap_scan_with_quiet_mode', 'sqlmap_scan_with_verbosity', 'sqlmap_scan_for_os_command_injection', 'sqlmap_scan_for_os_command_injection_using_shell', 'sqlmap_scan_for_os_command_injection_with_wildcards', 'sqlmap_scan_for_local_file_inclusion', 'sqlmap_scan_for_remote_file_inclusion', 'sqlmap_scan_for_file_read', 'sqlmap_scan_for_file_upload', 'sqlmap_cleanup', 'sqlmap_scan_with_custom_payload', 'sqlmap_scan_with_multiple_payloads', 'sqlmap_scan_with_random_payloads', 'sqlmap_scan_for_reflected_xss', 'sqlmap_scan_for_stored_xss', 'sqlmap_scan_for_dom_xss', 'sqlmap_scan_for_mysql_version', 'sqlmap_scan_for_postgresql_version', 'sqlmap_scan_for_oracle_version', 'sqlmap_scan_for_mssql_version', 'sqlmap_scan_with_error_handling',
           'get_google_answer','getgoogleanswer','nmap_scan', 'nmap_intense_scan', 'nmap_quick_scan', 'nmap_ping_sweep', 'nmap_os_detection', 'nmap_service_version_detection', 'nmap_tcp_connect_scan', 'nmap_syn_scan', 'nmap_udp_scan', 'nmap_traceroute_scan', 'nmap_vulnerability_scan', 'nmap_stealth_scan', 'nmap_ack_scan', 'nmap_window_scan', 'nmap_masquerade_scan', 'nmap_decoy_scan', 'nmap_fin_scan', 'nmap_xmas_scan', 'nmap_null_scan', 'nmap_ping_scan', 'nmap_sweep_scan', 'nmap_ftp_scan', 'nmap_smtp_scan', 'nmap_dns_scan', 'nmap_http_scan', 'nmap_pop3_scan', 'nmap_ssh_scan', 'nmap_mysql_scan', 'nmap_smb_vuln_scan', 'nmap_http_favicon_scan', 'nmap_smb_share_scan', 'nmap_traffic_analysis', 'nmap_smtp_vuln_scan', 'nmap_rdp_vuln_scan', 'nmap_irc_scan', 'nmap_ldap_scan', 'nmap_snmp_scan', 'nmap_dns_vuln_scan', 'nmap_http_auth_scan', 'nmap_telnet_scan', 'nmap_mysql_brute_scan', 'nmap_smb_info_scan', 'nmap_nfs_scan', 'nmap_mongodb_scan', 'nmap_dhcp_scan', 'nmap_vnc_scan', 'nmap_ftp_anonymous_scan', 'nmap_smtp_enum_scan', 'nmap_ftp_banners_scan', 'nmap_smb_enum_users_scan', 'nmap_ssh_enum_users_scan', 'nmap_pop3_brute_scan', 'nmap_tcp_ping_scan', 'nmap_ssl_scan', 'nmap_ssl_vuln_scan', 'nmap_smb_file_scan', 'nmap_ftp_banners_scan', 'nmap_vuln_detection_scan', 'nmap_smtp_open_scan', 'nmap_http_methods_scan', 'nmap_ssh_vuln_scan', 'nmap_http_xss_scan', 'nmap_ftp_anonymous_scan', 'nmap_dhcp_discovery_scan', 'nmap_nfs_mount_scan', 'nmap_smtp_brute_scan', 'nmap_smb_brute_scan', 'nmap_ldap_enum_scan', 'nmap_http_sitemap_scan', 'nmap_ftp_version_scan', 'nmap_snmp_community_scan', 'nmap_ssh_version_scan', 'nmap_mysql_info_scan', 'nmap_dns_zone_transfer_scan', 'nmap_pop3_vuln_scan', 'nmap_telnet_vuln_scan', 'nmap_imap_brute_scan', 'nmap_irc_banners_scan', 'nmap_http_ssl_scan', 'nmap_smb_vuln2_scan', 'nmap_http_robots_scan', 'nmap_mssql_brute_scan', 'nmap_smb_security_scan', 'nmap_smtp_starttls_scan', 'nmap_ftp_bypass_scan', 'nmap_dhcp_server_scan', 'nmap_dns_traceroute_scan', 'nmap_smtp_enum_vuln_scan', 'nmap_dns_dos_scan', 'nmap_rpc_scan', 'nmap_mongodb_bypass_scan', 'nmap_smb_enum_shares_scan', 'nmap_fingerprint_scan', 'nmap_snmp_enum_users_scan', 'nmap_ssl_certificate_scan', 'nmap_dhcp_lease_scan', 'nmap_mysql_enum_scan', 'nmap_http_security_scan', 'nmap_telnet_enum_scan', 'nmap_ftp_enumerate_scan', 'nmap_smb_enum_users_scan', 'nmap_pop3_enum_scan', 'nmap_smtp_enum_scan', 'nmap_http_cookie_scan', 'nmap_dhcp_fingerprint_scan', 'nmap_smb_enum_shares_users_scan', 'nmap_ftp_version_vuln_scan', 'nmap_smb_session_scan', 'nmap_telnet_enumerate_scan', 'nmap_smtp_vuln_scan', 'nmap_finger_scan', 'nmap_ftp_login_scan', 'nmap_ssh_brute_scan', 'nmap_http_ssl_cc_scan', 'nmap_smtp_starttls_vuln_scan', 'nmap_https_ping_scan', 'nmap_http_user_agent_scan', 'nmap_http_open_redirect_scan', 'nmap_smb_domain_info_scan', 'nmap_rdp_scan', 'nmap_dns_recursion_scan', 'nmap_http_ssl_scan', 'nmap_mongodb_auth_scan', 'nmap_http_basic_auth_brute_scan', 'nmap_ftp_vuln_scan', 'nmap_snmp_enumerate_users_scan', 'nmap_ssl_scan', 'nmap_netbios_scan', 'nmap_mysql_enum_vuln_scan', 'nmap_dns_scan', 'nmap_fingerprint_scan', 'nmap_smb_enum_machine_scan', 'nmap_smtp_tls_vuln_scan',
           'execute_command', 'cmd_list_files', 'cmd_get_disk_usage', 'cmd_get_memory_usage', 'cmd_get_running_processes', 'cmd_kill_process', 'cmd_create_directory', 'cmd_delete_file_or_directory', 'cmd_get_system_uptime', 'cmd_get_kernel_version', 'cmd_get_system_load', 'cmd_check_for_updates', 'cmd_install_package', 'cmd_uninstall_package', 'cmd_get_active_users', 'cmd_get_ip_address', 'cmd_check_firewall_status', 'cmd_flush_dns_cache', 'cmd_get_system_temperature', 'cmd_reset_tcpip_stack', 'cmd_check_disk_for_errors', 'cmd_restart_system', 'cmd_shutdown_system', 'cmd_open_control_panel', 'cmd_open_task_manager', 'cmd_check_services', 'cmd_start_service', 'cmd_stop_service', 'cmd_view_env_variables',
           'get_function_names_from_python_file','install_and_setup_nmap',
           'check_file_existence','create_directory','download_file','get_file_size','get_file_last_modified','rename_file','delete_file','move_file','extract_zip','compress_files','get_url_status','fetch_url_content','download_files_from_urls','get_files_in_directory','count_lines_in_file','get_current_datetime','get_extension','get_file_name_without_extension','get_file_type','move_files_to_directory','mysql_execute_advanced_mode',
           'engine_save_model','engine_load_model','engine_tensor_add','engine_tensor_dot','engine_sigmoid_activation','engine_dense_layer','engine_sgd_optimizer','engine_mse_loss','test_engine_functions',
           'overwritetextfile','text_file_operations_advanced_mode','overwritebinaryfile','binary_file_operations_advanced_mode','overwritecsvfile','csv_file_operations_advanced_mode',
           'extract_text_from_pdf','save_text_to_file','list_append_item', 'list_remove_item', 'list_insert_item', 'list_pop_item', 'list_find_index', 'list_contains_item', 'list_sort', 'list_reverse', 'list_clear', 'list_copy', 'list_extend', 'list_count', 'list_min', 'list_max', 'list_sum', 'list_mean', 'list_unique', 'list_combine', 'list_difference', 'list_intersection', 'list_is_empty',
           'str_reverse', 'str_to_upper', 'str_to_lower', 'str_is_palindrome', 'str_count_occurrences', 'str_is_alpha', 'str_is_digit', 'str_find_substring', 'str_replace_substring', 'str_split_words', 'str_strip_spaces', 'str_startswith', 'str_endswith', 'str_isalnum', 'str_title_case', 'str_concat, str_join','str_concat', 'str_join',
           'dict_add_key_value', 'dict_remove_key', 'dict_get_value', 'dict_update_value', 'dict_contains_key', 'dict_get_all_keys', 'dict_get_all_values', 'dict_clear', 'dict_copy', 'dict_items', 'dict_pop_item', 'dict_update', 'dict_setdefault', 'dict_fromkeys', 'dict_get_key_with_max_value', 'dict_get_key_with_min_value',
           'adv_gcd', 'adv_lcm', 'adv_prime_factors', 'adv_is_prime', 'adv_modular_exponentiation', 'adv_is_perfect_square', 'adv_fast_fourier_transform', 'adv_hash_string', 'adv_fast_modular_inverse', 'adv_fibonacci', 'adv_sieve_of_eratosthenes', 'adv_modular_square_root', 'adv_random_prime', 'adv_sum_of_squares', 'adv_calculate_modular_power', 'adv_combinations', 'adv_permutations','len_prime'
           
]
